@@ -44,6 +44,8 @@ flextable(tab1.df) %>%
   align(align = "left", part = "all") %>%
   
   footnote(i = 1, j = 2, value = as_paragraph(" Pr DF: Probability of disease freedom."), ref_symbols = " a", part = "body", inline = FALSE, sep = "; ") %>%
+  
+  fontsize(size = 9, part = "footer") %>%
 
   set_caption("Table 1: Functions to estimate sample size using representative population sampling data.")
 
@@ -105,6 +107,8 @@ flextable(tab2.df) %>%
   align(align = "left", part = "all") %>%
   
   footnote(i = 3, j = 3, value = as_paragraph(" mult comp: Multiple components."), ref_symbols = " a", part = "body", inline = FALSE, sep = "; ") %>%
+  
+  fontsize(size = 9, part = "footer") %>%
 
   set_caption("Table 2: Functions to estimate surveillance system sensitivity (SSe) using representative population sampling data.")
 
@@ -158,6 +162,8 @@ flextable(tab3.df) %>%
   footnote(i = 1, j = 2, value = as_paragraph(" Pr DF: Probability of disease freedom."), ref_symbols = " a", part = "body", inline = FALSE, sep = "; ") %>%
   
   footnote(i = 2, j = 2, value = as_paragraph(" Equilibrium pr DF: Equilibrium probability of disease freedom."), ref_symbols = " a", part = "body", inline = FALSE, sep = "; ") %>%
+  
+  fontsize(size = 9, part = "footer") %>%
 
   set_caption("Table 3: Functions to estimate the probability of disease freedom using representative population sampling data.")
 
@@ -187,7 +193,7 @@ ggplot(data = gdat.df, aes(x = mchar, y = prob, group = class, col = class)) +
   scale_y_continuous(limits = c(0,1), name = "Probability") +
   geom_hline(aes(yintercept = 0.95), linetype = "dashed", col = "blue") +
   guides(col = guide_legend(title = "")) +
-  theme(legend.position = c(0.8, 0.5))
+  theme(legend.position = "inside", legend.position.inside = c(0.8,0.5))
 
 ## ----ssrb.tab, echo=FALSE, message=FALSE, warnings=FALSE, results='asis'------
 tab4.df <- data.frame(
@@ -218,18 +224,20 @@ flextable(tab4.df) %>%
   align(align = "left", part = "all") %>%
   
   footnote(i = 1, j = 3, value = as_paragraph(" RGs: Risk groups."), ref_symbols = " a", part = "body", inline = FALSE, sep = "; ") %>%
+  
+  fontsize(size = 9, part = "footer") %>%
 
   set_caption("Table 4: Functions to estimate sample size using risk based sampling data.")
 
 ## ----message = FALSE----------------------------------------------------------
-# Matrix listing the proportions of samples for each test in each risk group (the number of rows equal the number of risk groups, the number of columns equal the number of tests):
+# Generate a matrix listing the proportions of samples for each test in each risk group (the number of rows equal the number of risk groups, the number of columns equal the number of tests):
 m <- rbind(1,1,1)
 
 rsu.sssep.rbmrg(pstar = 0.01, rr = c(5,3,1), ppr = c(0.1,0.1,0.8),
    spr = c(0.4,0.4,0.2), spr.rg = m, se.p = 0.95, se.u = 0.95)
 
 ## ----message = FALSE----------------------------------------------------------
-# Matrix listing the proportions of samples for each test in each risk group (the number of rows equal the number of risk groups, the number of columns equal the number of tests):
+# Generate a matrix listing the proportions of samples for each test in each risk group (the number of rows equal the number of risk groups, the number of columns equal the number of tests):
 m <- rbind(c(0.8,0.2), c(0.5,0.5), c(0.7,0.3))
 
 rsu.sssep.rbmrg(pstar = 0.01, rr = c(5,3,1), ppr = c(0.1,0.1,0.8),
@@ -278,6 +286,8 @@ flextable(tab4.df) %>%
   fontsize(i = 1, size = 8, part = "footer") %>%
   
   footnote(i = 1, j = 3, value = as_paragraph(" RGs: Risk groups."), ref_symbols = " a", part = "body", inline = FALSE, sep = "; ") %>%
+  
+  fontsize(size = 9, part = "footer") %>%
 
   set_caption("Table 5: Functions to estimate surveillance system sensitivity using risk based sampling data.")
 
